@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Module.
-use File::Temp qw(tempfile);
+use File::Temp;
 use IO::Barf;
 
 # Content.
